@@ -310,7 +310,7 @@ class DistributedScheduler(object):
             if self.old_ip != self.my_ip:
                 self.logger.info("Changed Public IP: {old} -> {new}".format(
                     old=self.old_ip, new=self.my_ip))
-                if self.old_ip is not None and self.my_ip != '52.28.30.162':
+                if self.old_ip != '127.0.0.1' and self.my_ip != '52.28.30.162':
                     self.signals.send_catch_log_deferred(signal=bhf_signals.ip_changed)
         except IOError:
             self.logger.error("Could not reach out to get public ip")
